==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedIterator.h <==
// class java.util.Collections$SynchronizedIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff59919a089a415 java_util_Collections__24SynchronizedIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24SynchronizedIterator_H_
#define _JC_java_util_Collections__24SynchronizedIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedIterator$sub_refs	_jc_java_util_Collections__24SynchronizedIterator$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs	_jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$refs	_jc_java_util_Collections__24SynchronizedIterator$refs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$nonrefs	_jc_java_util_Collections__24SynchronizedIterator$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$object	_jc_java_util_Collections__24SynchronizedIterator$object;

typedef const struct _jc_java_util_Collections__24SynchronizedIterator$vmethods	_jc_java_util_Collections__24SynchronizedIterator$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedIterator$vtable	_jc_java_util_Collections__24SynchronizedIterator$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedIterator$vtype	_jc_java_util_Collections__24SynchronizedIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedIterator$method$_init$2e16979936fb5500(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24SynchronizedIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *);
extern void _jc_java_util_Collections__24SynchronizedIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_Collections__24SynchronizedIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_Collections__24SynchronizedIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedIterator$vmethods	java_util_Collections__24SynchronizedIterator;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedIterator$sub_refs {
	struct _jc_java_lang_Object$object	*mutex;
	struct _jc_object	*i;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedIterator$refs {
    _jc_java_util_Collections__24SynchronizedIterator$sub_refs	java_util_Collections__24SynchronizedIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs	java_util_Collections__24SynchronizedIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedIterator$object {
	_jc_java_util_Collections__24SynchronizedIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedIterator$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedIterator$vtype _jc_java_util_Collections__24SynchronizedIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedIterator$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedIterator.h <==
// class java.util.Collections$SynchronizedIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff59919a089a415 java_util_Collections__24SynchronizedIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24SynchronizedIterator_H_
#define _JC_java_util_Collections__24SynchronizedIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedIterator$sub_refs	_jc_java_util_Collections__24SynchronizedIterator$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs	_jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$refs	_jc_java_util_Collections__24SynchronizedIterator$refs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$nonrefs	_jc_java_util_Collections__24SynchronizedIterator$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedIterator$object	_jc_java_util_Collections__24SynchronizedIterator$object;

typedef const struct _jc_java_util_Collections__24SynchronizedIterator$vmethods	_jc_java_util_Collections__24SynchronizedIterator$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedIterator$vtable	_jc_java_util_Collections__24SynchronizedIterator$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedIterator$vtype	_jc_java_util_Collections__24SynchronizedIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedIterator$method$_init$2e16979936fb5500(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24SynchronizedIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24SynchronizedIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_Collections__24SynchronizedIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_Collections__24SynchronizedIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedIterator$vmethods	java_util_Collections__24SynchronizedIterator;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedIterator$sub_refs {
	struct _jc_java_lang_Object$object	*mutex;
	struct _jc_object	*i;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedIterator$refs {
    _jc_java_util_Collections__24SynchronizedIterator$sub_refs	java_util_Collections__24SynchronizedIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs	java_util_Collections__24SynchronizedIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedIterator$object {
	_jc_java_util_Collections__24SynchronizedIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedIterator$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedIterator$vtype _jc_java_util_Collections__24SynchronizedIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedIterator$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedIterator_H_ */
